@@ -71,6 +71,9 @@ class CiviCRM_For_WordPress_Compat {
     // Support Clean URLs when Polylang is active.
     add_action('civicrm_after_rewrite_rules', [$this, 'rewrite_rules_polylang'], 10, 2);
 
+    // Prevent AIOSEO from stomping on CiviCRM Shortcodes.
+    add_filter('aioseo_conflicting_shortcodes', [$this, 'aioseo_resolve_conflict']);
+
   }
 
   /**
@@ -79,7 +82,7 @@ class CiviCRM_For_WordPress_Compat {
    * @since 5.24
    *
    * @param bool $flush_rewrite_rules True if rules flushed, false otherwise.
-   * @param WP_Post $basepage The Basepage post object.
+   * @param WP_Post $basepage The Base Page post object.
    */
   public function rewrite_rules_polylang($flush_rewrite_rules, $basepage) {
 
@@ -92,12 +95,12 @@ class CiviCRM_For_WordPress_Compat {
      * Collect all rewrite rules into an array.
      *
      * Because the array of specific Post IDs is added *after* the array of
-     * paths for the Basepage ID, those specific rewrite rules will "win" over
-     * the more general Basepage rules.
+     * paths for the Base Page ID, those specific rewrite rules will "win" over
+     * the more general Base Page rules.
      */
     $collected_rewrites = [];
 
-    // Support prefixes for a single Basepage.
+    // Support prefixes for a single Base Page.
     $basepage_url = get_permalink($basepage->ID);
     $basepage_raw_url = PLL()->links_model->remove_language_from_link($basepage_url);
     $language_slugs = pll_languages_list();
@@ -113,7 +116,7 @@ class CiviCRM_For_WordPress_Compat {
       }
     };
 
-    // Support prefixes for Basepages in multiple languages.
+    // Support prefixes for Base Pages in multiple languages.
     foreach ($language_slugs as $slug) {
       $post_id = pll_get_post($basepage->ID, $slug);
       if (empty($post_id)) {
@@ -147,4 +150,19 @@ class CiviCRM_For_WordPress_Compat {
 
   }
 
+  /**
+   * Fixes AIOSEO's attempt to modify Shortcodes.
+   *
+   * @see https://civicrm.stackexchange.com/questions/40765/wp-all-in-one-seo-plugin-conflict
+   *
+   * @since 5.45
+   *
+   * @param array $conflicting_shortcodes The existing AIOSEO Conflicting Shortcodes array.
+   * @return array $conflicting_shortcodes The modified AIOSEO Conflicting Shortcodes array.
+   */
+  public function aioseo_resolve_conflict($conflicting_shortcodes) {
+    $conflicting_shortcodes['CiviCRM'] = 'civicrm';
+    return $conflicting_shortcodes;
+  }
+
 }
